.. _usage-text:

Text analysis
==================================
The :doc:`dhlab.text <generated/text>` subpackage contains functionality for processing text data
in the digital collection `NB Digital`_.

.. todo:: Add sections about

   * tokenisation
   * corpus building
   * collocations
   * concordances

   (what it is and how it's done in dhlab)



Use
-------------------------------------
Import text processing functions and classes from :doc:`generated/text` like this:

.. code-block:: python

   from dhlab.text import ...

--------------------------------------------------------------

.. _NB Digital: https://www.nb.no/search

